@@ -252,6 +252,7 @@ board <- R6Class(classname = 'Board',
                    g.bets = NULL,
                    o.bets = NULL,
 
+
                    winner.bets = NULL,
                    loser.bets = NULL,
                    initialize = function(sys){
@@ -317,7 +318,7 @@ board <- R6Class(classname = 'Board',
 
 
                      camel.m <- self$tot.camels[[index]]
-                     # print(c(camel.m$print(), camel.m$position))
+                     print(c(camel.m$print(), camel.m$position, dis))
                      if(self$spaces[[camel.m$position + dis]]$plus.tile == FALSE &
                         self$spaces[[camel.m$position + dis]]$minus.tile == FALSE){
                        camel.m$move(dis)
@@ -428,7 +429,7 @@ board <- R6Class(classname = 'Board',
                    },
 
                    check.end.leg = function() {
-                     if(length(self$dice.left) == 0)
+                     if(length(self$dice.left) == 0 | self$check.end.game())
                        return(TRUE)
                      else
                        return(FALSE)
@@ -436,8 +437,10 @@ board <- R6Class(classname = 'Board',
 
                    check.end.game = function() {
                      for(cam in self$tot.camels){
-                       if(cam$position > 16)
+                       if(cam$position > 16){
+
                          return(TRUE)
+                       }
                      }
                      return(FALSE)
                    },
@@ -693,6 +696,7 @@ player <- R6Class(classname = 'Player',
 #' System class that manages overall game play
 #'
 #' @import tidyverse
+#' @import parallel
 #'
 #' @export system
 #' @exportClass system
@@ -706,6 +710,7 @@ system <- R6Class(classname = 'System',
                     players = NULL,
                     current.player = NULL,
                     simData = NULL,
+                    gameOver = FALSE,
 
                     # Initialize system object
                     initialize = function(nPlayers = NULL, players = NULL, isDup = FALSE){ #NEW
@@ -735,13 +740,24 @@ system <- R6Class(classname = 'System',
                     simGame = function(action, nDiceSeq){
 
                       # print("sim game")
+                      currentPurse <- self$players[[self$current.player]]$purse
                       sim <- self$duplicate()
                       name <- self$players[[self$current.player]]$name
                       #nDiceLeft <- length(self$board$dice.left)
+                      lastNumDice <- max(nDiceSeq)
                       if (action == "move"){
                         for(i in nDiceSeq){
-                          sim$take.turn("move", TRUE)
+                          if(!sim$gameOver){
+                            # lastNumDice <- length(sim$board$dice.left)
+                            sim$take.turn("move", TRUE)
+
+                          }
+
                         }
+                        # while(!sim$board$check.end.leg()){
+                        #   sim$take.turn("move", TRUE)
+                        #
+                        # }
                       } else if (stringr::str_detect(action, "winner") | stringr::str_detect(action, "loser")){
                         sim$take.turn(action)
                         while(!sim$board$check.end.game()){
@@ -750,10 +766,13 @@ system <- R6Class(classname = 'System',
                       } else {
                         sim$take.turn(action)
                         for(i in nDiceSeq){
-                          sim$take.turn("move", TRUE)
+                          if(!sim$gameOver){
+                            # lastNumDice <- length(sim$board$dice.left)
+                            sim$take.turn("move", TRUE)
+                          }
                         }
                       }
-                      currentPurse <- 3 #self$players[[self$current.player]]$purse
+
                       result <- sim$initial_record(name, currentPurse)
                       # print(result)
                       result <- data.table::as.data.table(result)
@@ -775,7 +794,7 @@ system <- R6Class(classname = 'System',
                       # for(i in 1:nSims) {
                       #   camelResults <- rbind(camelResults, self$simGame(action, nDiceSeq))
                       # }
-                      numCores <- detectCores() - 1
+                      numCores <- parallel::detectCores() - 1
                       # my_cluster <- makeCluster(num_cores)
                       # force(self)
                       temp <- self$duplicate()
@@ -797,6 +816,7 @@ system <- R6Class(classname = 'System',
 
 
                     take.turn = function(input = NULL, isSim = FALSE){
+
                       if(is.null(input)){
                         input <- readline(prompt = paste(c(self$players[[self$current.player]]$name, ", it is your turn. What would you like to do? "), collapse = ''))
                       }
@@ -884,6 +904,7 @@ system <- R6Class(classname = 'System',
 
                         self$eval.leg()
                         self$eval.end.game()
+                        self$gameOver <- TRUE
 
                         max <- 0
                         game.winner <- NA
@@ -910,6 +931,7 @@ system <- R6Class(classname = 'System',
 
                       self$print()
                       return(dispText)
+
                     },
 
                     increase.current.player = function(){
@@ -1153,13 +1175,13 @@ system <- R6Class(classname = 'System',
                         plt <- ggplot2::ggplot(data, ggplot2::aes(x = X, y = Y)) +
                           ggplot2::geom_blank() +
                           ggplot2::coord_cartesian(xlim = c(1, 19),
-                                          ylim = c(0.49, 5.49)) +
+                                                   ylim = c(0.49, 5.49)) +
                           ggplot2::scale_x_continuous(breaks = 1:19) +
                           ggplot2::geom_vline(xintercept = 16.5) +
                           ggplot2::theme_classic() +
                           ggplot2::guides(color = FALSE, size = FALSE) +
                           ggplot2::theme(legend.background = ggplot2::element_rect(colour = 'black', fill = 'white', linetype='solid'),
-                                legend.key = ggplot2::element_rect(color = "black"))
+                                         legend.key = ggplot2::element_rect(color = "black"))
                         return(plt)
                       }
 
@@ -1168,13 +1190,13 @@ system <- R6Class(classname = 'System',
                         ggplot2::geom_tile() +
                         ggplot2::scale_fill_manual(values = camelColors) +
                         ggplot2::coord_cartesian(xlim = c(1, 19),
-                                        ylim = c(0.49, 5.49)) +
+                                                 ylim = c(0.49, 5.49)) +
                         ggplot2::scale_x_continuous(breaks = 1:19, labels = (paste(1:19, tiles[[2]], sep = "\n"))) +
                         ggplot2::geom_vline(xintercept = 16.5) +
                         ggplot2::theme_classic() +
                         ggplot2::guides(color = FALSE, size = FALSE) +
                         ggplot2::theme(legend.background = ggplot2::element_rect(colour = 'black', fill = 'white', linetype='solid'),
-                              legend.key = ggplot2::element_rect(color = "black"))
+                                       legend.key = ggplot2::element_rect(color = "black"))
                       return(plt)
                     },
 
@@ -1194,10 +1216,19 @@ system <- R6Class(classname = 'System',
 
                       filteredData <- dplyr::filter(data, Color == color)
 
-                      avg <- mean(filteredData$X)
-                      stdDevX <- sd(filteredData$X)
+                      if(type != "purse"){
+                        avg <- mean(filteredData$X)
+                        stdDevX <- sd(filteredData$X)
+                      } else {
+                        playerData <- dplyr::filter(data, Color == "Player")
+                        avg <- mean(playerData$X)
+                        stdDevX <- sd(playerData$X)
+                        vLines <- NULL
+                      }
+
+
+                      if(length(vLinesBool) > 0){
 
-                      if(length(vLinesBool) >0){
                         expVal <- eval(vLinesBool[1])
                         std1 <- eval(vLinesBool[2])
                         std2 <- eval(vLinesBool[3])
@@ -1218,37 +1249,42 @@ system <- R6Class(classname = 'System',
                       }
 
                       if(type == "stack"){
+
                         tempData <- dplyr::group_by(filteredData, X, Y)
                         tempData <- dplyr::summarize(tempData, "count" = n())
                         tempData <- dplyr::mutate(tempData, Probability = count/sum(tempData$count))
 
                         plt <- ggplot2::ggplot(tempData, ggplot2::aes(x = X, y = Y), width = 10) +
                           ggplot2::geom_tile(ggplot2::aes(alpha = Probability), color = "black", fill = ifelse(color == "White",
-                                                                                             "black",
-                                                                                             color)) +
+                                                                                                               "black",
+                                                                                                               color),
+                                             width = 0.9) +
                           ggplot2::coord_cartesian(xlim = c(1, 19)) +
-                          ggplot2::ylim(0.49, 5.49) +
+                          ggplot2::ylim(0, 5.49) +
                           ggplot2::scale_x_continuous(breaks = 1:19) +
+                          ggplot2::scale_y_continuous(labels = c("0.00", "1.00", "2.00", "3.00", "4.00", "5.00"),
+                                                      breaks = 0:5) +
                           ggplot2::geom_vline(xintercept = vLines) +
                           ggplot2::theme_classic() +
                           ggplot2::labs(x = "Space",
-                               y = "Height",
-                               title = paste("2-Dimensional Plot of Camel Simulation Results. Mean = ", round(mean(tempData$X,2)), ". ", "Std. Dev. = ", round(sd(tempData$X),2)))
+                                        y = "Height",
+                                        title = paste("2-Dimensional Plot of Camel Simulation Results. Mean = ", round(mean(filteredData$X), 4), ". ", "Std. Dev. = ", round(sd(filteredData$X), 4)))
                         #print("test")
                         #print(mean(tempData$X))
                       }
                       if(type == "space"){
-                        tempData <- dplyr::filter(filteredData, Color == color)
-                        tempData <- dplyr::group_by(tempData, X)
+                        Camel <- "blue"
+                        tempData <- dplyr::group_by(filteredData, X)
                         tempData <- dplyr::summarize(tempData, "count" = n())
                         tempData <- dplyr::mutate(tempData, "Probability" = count/nSims)
 
                         plt <- ggplot2::ggplot(tempData, ggplot2::aes(x = X, y = Probability)) +
                           ggplot2::geom_bar(stat = "identity",
-                                   fill = ifelse(color == "White",
-                                                 "black",
-                                                 color),
-                                   width = 0.9) +
+                                            fill = ifelse(color == "White",
+                                                          "black",
+                                                          color),
+                                            mapping = ggplot2::aes(color = color),
+                                            width = 0.9) +
                           ggplot2::geom_text(ggplot2::aes(label = round(Probability, 3)), position=ggplot2::position_dodge(width=0.9), vjust=-0.25) +
                           ggplot2::coord_cartesian(xlim = c(1, 19)) +
                           ggplot2::scale_x_continuous(breaks = 1:19) +
@@ -1256,8 +1292,13 @@ system <- R6Class(classname = 'System',
                           ggplot2::geom_vline(xintercept = vLines) +
                           ggplot2::theme_classic() +
                           ggplot2::labs(x = "Space",
-                               y = "Probability",
-                               title = paste("Space vs. Probability Simulation Results. Mean = ", round(mean(tempData$X,2)), ". ", "Std. Dev. = ", round(sd(tempData$X),2)))
+                                        y = "Probability",
+                                        title = paste("Space vs. Probability Simulation Results. Mean = ", round(mean(filteredData$X), 4), ". ", "Std. Dev. = ", round(sd(filteredData$X), 4))) +
+                          ggplot2::scale_color_manual("Camel",
+                                                      values = "black",
+                                                      breaks = color)
+
+
                       }
                       if(type == "purse"){
                         tempData <- dplyr::filter(data, Color == "Player")
@@ -1268,18 +1309,18 @@ system <- R6Class(classname = 'System',
                         print(tempData)
                         plt <- ggplot2::ggplot(tempData, ggplot2::aes(x = X, y = Probability)) +
                           ggplot2::geom_bar(stat = "identity",
-                                   fill = ifelse(color == "White",
-                                                 "black",
-                                                 color)
-                                   , width = 0.9) +
+                                            fill = ifelse(color == "White",
+                                                          "black",
+                                                          color)
+                                            , width = 0.9) +
                           ggplot2::geom_text(ggplot2::aes(label = round(Probability, 3)), position=ggplot2::position_dodge(width=0.9), vjust=-0.25) +
-                          ggplot2::scale_x_continuous(breaks = -1:5) +
+                          ggplot2::scale_x_continuous(breaks = -1:10) +
                           ggplot2::ylim(0,1)+
                           ggplot2::geom_vline(xintercept = vLines) +
                           ggplot2::theme_classic() +
                           ggplot2::labs(x = "Number of Coins",
-                               y = "Probability",
-                               title = paste0("Purse vs. Probability Simulation Results. Mean = ", round(mean(tempData$X,2)), ". ", "Std. Dev. = ", round(sd(tempData$X),2)))
+                                        y = "Probability",
+                                        title = paste0("Purse vs. Probability Simulation Results. Mean = ", round(mean(tempData$X), 2)), ". ", "Std. Dev. = ", round(sd(tempData$X),2))
                         #coord_cartesian(xlim = c(1, 19)) +
                         #ggplot2::scale_x_continuous(breaks = 1:19) +
                         #ggplot2::geom_vline(xintercept = 17) +
